Learn R Programming

perARMA (version 1.6)

perARMA-package: Periodic Time Series Analysis and Modeling

Description

This package provides procedures for periodic time series analysis. The package includes procedures for nonparametric spectral analysis and parametric (PARMA) identification, estimation/fitting and prediction. The package is equipped with three examples of periodic time series: volumes and volumes.sep, which record hourly volumes of traded energy, and arosa containing monthly ozone levels.

Arguments

Details

Package:
perARMA
Type:
Package
Version:
1.6
Date:
2016-02-25
License:
GPL(>=2.0)
LazyLoad:
yes
The main routines are: Nonparametric spectral analysis: pgram, scoh Preliminary identification and conditioning: permest, persigest Identification: peracf, Bcoeff, perpacf, acfpacf Parameter estimation/fitting: perYW, loglikec, parmaf, loglikef Prediction: predictperYW, predseries Simulation and testing: makeparma, parma_ident

For a complete list of procedures use library(help="perARMA"). For short overview some of the procedures in Matlab version see the webpage: http://www.unc.edu/~hhurd/pc-sequences/book_progs_data.html.

References

Hurd, H. L., Miamee, A. G., (2007), Periodically Correlated Random Sequences: Spectral Theory and Practice, Wiley InterScience.

See Also

Packages for Periodic Autoregression Analysis link{pear}, Dynamic Systems Estimation link{dse} and Bayesian and Likelihood Analysis of Dynamic Linear Models link{dlm}.

Examples

Run this code
## Do not run
## It could take more than one minute
#demo(perARMA)

Run the code above in your browser using DataLab