T is known, procedure permest plots and returns the estimated periodic
mean as a function of season. Missing data are permitted.
The confidence intervals for these values, based on the t-distribution, are also computed
and plotted. The de-meaned x is also returned with missing values
replaced by periodic mean values.
If at time t there is a missing value,
it is replaced with the periodic mean at (t mod T), provided the periodic mean exists (meaning there is at least one non-missing data for the
season (t mod T)). Otherwise the periodic mean at (t mod T) will be set to "Missing" and in the output vectors
xr and xd all the values whose times are congruent with (t mod T) will be set to "Missing".
permest(x, T, alpha, missval, datastr,...)1-alpha is confidence interval containment probability using the t-distribution.
typeci, typepmean, pchci, pchpmean, colci, colpmean, pp;
typeci / typepmean, pchci / pchpmean, colci / colpmean set the type, plot character and colors of confidence
intervals / periodic mean values on the plot,
pp should be positive to print and plot permest values.
By default these parameters are fixed to typeci = "o", typepmean = "b", pchci = 10, pchpmean = 15, colci = "red", colpmean = "blue", pp = 1.
NaN)
and the length of the series need not be
an integer multiple of the period. The program returns
and plots the periodic mean with 1-alpha confidence
intervals based on all non-missing values present for each
particular season. The p-value for a one-way
ANOVA test for equality of seasonal means is also computed.
Westfall, P. H., Young, S. S. (1993), Resampling-Based Multiple Testing: Examples and Methods for p-Value Adjustment, Wiley Series in Probability and Statistics.
persigest
data(arosa)
dev.set(which=1)
permest(t(arosa),12, 0.05, NaN,'arosa')
Run the code above in your browser using DataLab