volumes and volumes.sep,
which record hourly volumes of traded energy, and arosa containing monthly ozone
levels.
| Package: |
| perARMA |
| Type: |
| Package |
| Version: |
| 1.6 |
| Date: |
| 2016-02-25 |
| License: |
| GPL(>=2.0) |
| LazyLoad: |
| yes |
pgram, scoh
Preliminary identification and conditioning: permest, persigest
Identification: peracf, Bcoeff, perpacf, acfpacf
Parameter estimation/fitting: perYW, loglikec, parmaf, loglikef
Prediction: predictperYW, predseries
Simulation and testing: makeparma, parma_identFor a complete list of procedures use library(help="perARMA").
For short overview some of the procedures in Matlab version see the webpage:
http://www.unc.edu/~hhurd/pc-sequences/book_progs_data.html.
link{pear},
Dynamic Systems Estimation link{dse} and
Bayesian and Likelihood Analysis of Dynamic Linear Models link{dlm}.
## Do not run
## It could take more than one minute
#demo(perARMA)
Run the code above in your browser using DataLab